@@ -40,13 +40,10 @@ class PYBEHAVIOR:
 
     # Does Python conform to PEP626, Precise line numbers for debugging and other tools.
     # https://www.python.org/dev/peps/pep-0626
-    pep626 = CPYTHON and (PYVERSION > (3, 10, 0, "alpha", 4))
+    pep626 = (PYVERSION > (3, 10, 0, "alpha", 4))
 
     # Is "if __debug__" optimized away?
-    if PYPY:
-        optimize_if_debug = True
-    else:
-        optimize_if_debug = not pep626
+    optimize_if_debug = not pep626
 
     # Is "if not __debug__" optimized away? The exact details have changed
     # across versions.
@@ -55,18 +52,10 @@ class PYBEHAVIOR:
     elif PYPY:
         if PYVERSION >= (3, 9):
             optimize_if_not_debug = 2
-        elif PYVERSION[:2] == (3, 8):
+        else:
             optimize_if_not_debug = 3
-        else:
-            optimize_if_not_debug = 1
     else:
-        if PYVERSION >= (3, 8, 0, "beta", 1):
-            optimize_if_not_debug = 2
-        else:
-            optimize_if_not_debug = 1
-
-    # Can co_lnotab have negative deltas?
-    negative_lnotab = not (PYPY and PYPYVERSION < (7, 2))
+        optimize_if_not_debug = 2
 
     # 3.7 changed how functions with only docstrings are numbered.
     docstring_only_function = (not PYPY) and ((3, 7, 0, "beta", 5) <= PYVERSION <= (3, 10))
@@ -76,28 +65,11 @@ class PYBEHAVIOR:
     # does the finally jump back to the break/continue/return (3.8) to do the
     # work?
     finally_jumps_back = ((3, 8) <= PYVERSION < (3, 10))
-    if PYPY and PYPYVERSION < (7, 3, 7):
-        finally_jumps_back = False
-
-    # When a function is decorated, does the trace function get called for the
-    # @-line and also the def-line (new behavior in 3.8)? Or just the @-line
-    # (old behavior)?
-    trace_decorated_def = (
-        (PYVERSION >= (3, 8)) and
-        (CPYTHON or (PYVERSION > (3, 8)) or (PYPYVERSION > (7, 3, 9)))
-    )
-
-    # Functions are no longer claimed to start at their earliest decorator even though
-    # the decorators are traced?
-    def_ast_no_decorator = (PYPY and PYVERSION >= (3, 9))
 
     # CPython 3.11 now jumps to the decorator line again while executing
     # the decorator.
     trace_decorator_line_again = (CPYTHON and PYVERSION > (3, 11, 0, "alpha", 3, 0))
 
-    # Are while-true loops optimized into absolute jumps with no loop setup?
-    nix_while_true = (PYVERSION >= (3, 8))
-
     # CPython 3.9a1 made sys.argv[0] and other reported files absolute paths.
     report_absolute_files = (
         (CPYTHON or (PYPY and PYPYVERSION >= (7, 3, 10)))
@@ -137,6 +109,10 @@ class PYBEHAVIOR:
     # only a 0-number line, which is ignored, giving a truly empty module.
     empty_is_empty = (PYVERSION >= (3, 11, 0, "beta", 4))
 
+    # Are comprehensions inlined (new) or compiled as called functions (old)?
+    # Changed in https://github.com/python/cpython/pull/101441
+    comprehensions_are_functions = (PYVERSION <= (3, 12, 0, "alpha", 7, 0))
+
 # Coverage.py specifics.
 
 # Are we using the C-implemented trace function?
