@@ -124,6 +124,7 @@ class RecursionTest(CoverageTest):
         with swallow_warnings("Trace function changed, data is likely wrong: None"):
             self.start_import_stop(cov, "recur")
 
+        assert cov._collector is not None
         pytrace = (cov._collector.tracer_name() == "PyTracer")
         expected_missing = [3]
         if pytrace:                                 # pragma: no metacov
@@ -373,11 +374,10 @@ class ExceptionTest(CoverageTest):
             calls = [getattr(sys.modules[cn], cn) for cn in callnames_list]
 
             cov = coverage.Coverage()
-            cov.start()
-            # Call our list of functions: invoke the first, with the rest as
-            # an argument.
-            calls[0](calls[1:])     # pragma: nested
-            cov.stop()              # pragma: nested
+            with cov.collect():
+                # Call our list of functions: invoke the first, with the rest as
+                # an argument.
+                calls[0](calls[1:])
 
             # Clean the line data and compare to expected results.
             # The file names are absolute, so keep just the base.
