@@ -8,6 +8,7 @@ from __future__ import annotations
 import glob
 import os
 import os.path
+import platform
 import re
 import stat
 import sys
@@ -687,6 +688,14 @@ class EnvironmentTest(CoverageTest):
         actual = self.run_command("coverage run sub/overthere/prog.py")
         self.assert_tryexecfile_output(expected, actual)
 
+    @pytest.mark.skipif(not env.WINDOWS, reason="This is about Windows paths")
+    def test_coverage_run_far_away_is_like_python_windows(self) -> None:
+        with open(TRY_EXECFILE) as f:
+            self.make_file("sub/overthere/prog.py", f.read())
+        expected = self.run_command("python sub\\overthere\\prog.py")
+        actual = self.run_command("coverage run sub\\overthere\\prog.py")
+        self.assert_tryexecfile_output(expected, actual)
+
     def test_coverage_run_dashm_is_like_python_dashm(self) -> None:
         # These -m commands assume the coverage tree is on the path.
         expected = self.run_command("python -m process_test.try_execfile")
@@ -837,14 +846,23 @@ class EnvironmentTest(CoverageTest):
         assert "hello-xyzzy" in out
 
     @pytest.mark.skipif(env.WINDOWS, reason="Windows can't make symlinks")
+    @pytest.mark.skipif(
+        platform.python_version().endswith("+"),
+        reason="setuptools barfs on dev versions: https://github.com/pypa/packaging/issues/678"
+        # https://github.com/nedbat/coveragepy/issues/1556
+    )
     def test_bug_862(self) -> None:
-        # This simulates how pyenv and pyenv-virtualenv end up creating the
-        # coverage executable.
-        self.make_file("elsewhere/bin/fake-coverage", """\
-            #!{executable}
-            import sys, pkg_resources
-            sys.exit(pkg_resources.load_entry_point('coverage', 'console_scripts', 'coverage')())
-            """.format(executable=sys.executable))
+        # This used to simulate how pyenv and pyenv-virtualenv create the
+        # coverage executable.  Now the code shows how venv does it.
+        self.make_file("elsewhere/bin/fake-coverage", f"""\
+            #!{sys.executable}
+            import re
+            import sys
+            from coverage.cmdline import main
+            if __name__ == '__main__':
+                sys.argv[0] = re.sub(r'(-script\\.pyw|\\.exe)?$', '', sys.argv[0])
+                sys.exit(main())
+            """)
         os.chmod("elsewhere/bin/fake-coverage", stat.S_IREAD | stat.S_IEXEC)
         os.symlink("elsewhere", "somewhere")
         self.make_file("foo.py", "print('inside foo')")
